function writeJson(data, geneList, D, Y, C, filename)

    structureList = {'RSP','Tel','PedHy','p3','p2','p1','M','PPH','PH','PMH','MH','CSPall','DPall','MPall'};
    ageList = {'E11.5','E13.5','E15.5','E18.5','P4','P14','P28','P56'};

    % Open file
    fid = fopen(filename, 'w');
    fprintf(fid, '%s', '{"nodes":[');
    
    % Write nodes
    for i=1:size(data,1)
        
        s = ['{"name":"', structureList{data(i,1)+1},'_',ageList{data(i,3)+1},'","id":',num2str(i-1),',"struct":"',structureList{data(i,1)+1},'","depth":',num2str(data(i,2)+1),',"age":"',ageList{data(i,3)+1},'","group":',num2str(data(i,3)+1)];
        fprintf(fid, '%s', s);
        
        fprintf(fid, '%s', ',"genes":[{');
        if (all(data(i,4:end)==-1))
            fprintf(fid, '%s', ['"name":"None","measured":"false","expression":',num2str(1+data(i,2)+1),'}']);
        else
            fprintf(fid, '%s', ['"name":"None","measured":"true","expression":',num2str(1+data(i,2)+1),'}']);
        end
        for g=1:size(geneList,2)
            if data(i,g+3)==-1
                s = [',{"name":"',geneList{g},'","measured":"false","expression":0}'];
            else
                if (isnan(D(i,g)))
                    s = [',{"name":"',geneList{g},'","measured":"true","expression":',num2str(data(i,g+3)),'}'];
                else
                    s = [',{"name":"',geneList{g},'","measured":"true","expression":',num2str(data(i,g+3)),'}'];
                end
            end
            fprintf(fid, '%s', s);
        end
         fprintf(fid, '%s', ']');
        
        if (i<size(data,1))
            fprintf(fid, '%s', '},');
        else
            fprintf(fid, '%s', '}');
        end
    end
    fprintf(fid, '%s', '],"links":[');
    
    % Write vertical links
    index = 1;
    for aSource=1:(size(ageList,2)-1)
        aTarget = aSource+1;
        for sSource=1:size(structureList,2)
            indexSource = getIndex(aSource-1,sSource-1);
            for sTarget=1:size(structureList,2)
                indexTargetCorr = getIndex(aTarget-2,sTarget-1);
                indexTargetLink = getIndex(aTarget-1,sTarget-1);
                if (~isnan(Y(indexSource,indexTargetCorr)) && Y(indexSource,indexTargetCorr)<0.5)
                    if (index>1)
                        fprintf(fid, '%s', ',');
                    end
                    
                    s = ['{"name":"', structureList{data(indexSource,1)+1},'_',ageList{data(indexSource,3)+1},'-',structureList{data(indexTargetLink,1)+1},'_',ageList{data(indexTargetLink,3)+1},'","source":',num2str(indexSource-1),',"target":',num2str(indexTargetLink-1),',"type":"vertical"'];
                    fprintf(fid, '%s', s);
                    fprintf(fid, '%s', ',"values":[{');
                    s = ['"name":"None","distance":',num2str(Y(indexSource,indexTargetCorr)),'}'];
                    fprintf(fid, '%s', s);
%                     for g=1:size(geneList,2)
%                         s = [',{"name":"',geneList{g},'","distance":',num2str(getSingleCorr(g,indexSource,indexTargetCorr)),'}'];
%                         fprintf(fid, '%s', s);
%                     end

                    fprintf(fid, '%s', ']}');
                    
                    index = index+1;
                end
            end
        end
    end
    
    % Write horizonal links
    for aSource=1:(size(ageList,2)-1)
        aTarget = aSource;
        for sSource=1:size(structureList,2)
            indexSource = getIndex(aSource-1,sSource-1);
            for sTarget=1:size(structureList,2)
                indexTargetCorr = getIndex(aTarget-1,sTarget-1);
                indexTargetLink = getIndex(aTarget-1,sTarget-1);
                if (~isnan(C(indexSource,indexTargetCorr)) && indexSource~=indexTargetCorr && C(indexSource,indexTargetCorr)<0.5)
                    if (index>1)
                        fprintf(fid, '%s', ',');
                    end
                    
                    s = ['{"name":"', structureList{data(indexSource,1)+1},'_',ageList{data(indexSource,3)+1},'-',structureList{data(indexTargetLink,1)+1},'_',ageList{data(indexTargetLink,3)+1},'","source":',num2str(indexSource-1),',"target":',num2str(indexTargetLink-1),',"type":"horizontal"'];
                    fprintf(fid, '%s', s);
                    fprintf(fid, '%s', ',"values":[{');
                    s = ['"name":"None","distance":',num2str(C(indexSource,indexTargetCorr)),'}'];
                    fprintf(fid, '%s', s);
%                     for g=1:size(geneList,2)
%                         s = [',{"name":"',geneList{g},'","distance":',num2str(getSingleCorr(g,indexSource,indexTargetCorr)),'}'];
%                         fprintf(fid, '%s', s);
%                     end

                    fprintf(fid, '%s', ']}');
                    index = index+1;
                end
            end
        end
    end
    
    fprintf(fid, '%s', ']}');
    
    % Close file
    fclose(fid);
    
    function index = getIndex(ageId, structureId)
        index = 1 + ageId + size(ageList,2)*structureId;
    end

    function corr = getSingleCorr(g,i,j)
        if (isnan(D(i,g)) || isnan(D(j,g)))
            corr = 1;
        else
            corr = pdist([D(i,g);D(j,g)]);
        end
    end
    
end